PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/gaunt.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

gaunt.h
Go to the documentation of this file.
1
8 #ifndef GAUNT_H
9 #define GAUNT_H
10
11 extern double GAUNT_COEFF[4][4][4][7][4];
12 extern double SBTFACS[4][4][4][7][4];
13
14 #endif
GAUNT_COEFF
double GAUNT_COEFF[4][4][4][7][4]
SBTFACS
double SBTFACS[4][4][4][7][4]